@@ -14,6 +14,7 @@ from .event import (
     CameraMotionEvent,
     CameraPersonEvent,
     CameraSoundEvent,
+    EventImageContentType,
     EventImageType,
     EventTrait,
     ImageEventBase,
@@ -129,8 +130,7 @@ class RtspStream(Stream):
             "command": "sdm.devices.commands.CameraLiveStream.ExtendRtspStream",
             "params": {"streamExtensionToken": self.stream_extension_token},
         }
-        resp = await self._cmd.execute(data)
-        response_data = await resp.json()
+        response_data = await self._cmd.execute_json(data)
         results = response_data[RESULTS]
         # Update the stream url with the new token
         stream_token = results[STREAM_TOKEN]
@@ -182,8 +182,7 @@ class WebRtcStream(Stream):
             "command": "sdm.devices.commands.CameraLiveStream.ExtendWebRtcStream",
             "params": {MEDIA_SESSION_ID: self.media_session_id},
         }
-        resp = await self._cmd.execute(data)
-        response_data = await resp.json()
+        response_data = await self._cmd.execute_json(data)
         # Preserve original answerSdp, and merge with response that contains
         # the other fields (expiresAt, and mediaSessionId.
         results = response_data[RESULTS]
@@ -253,8 +252,7 @@ class CameraLiveStreamTrait:
             "command": "sdm.devices.commands.CameraLiveStream.GenerateRtspStream",
             "params": {},
         }
-        resp = await self._cmd.execute(data)
-        response_data = await resp.json()
+        response_data = await self._cmd.execute_json(data)
         results = response_data[RESULTS]
         return RtspStream(results, self._cmd)
 
@@ -266,8 +264,7 @@ class CameraLiveStreamTrait:
             "command": "sdm.devices.commands.CameraLiveStream.GenerateWebRtcStream",
             "params": {"offerSdp": offer_sdp},
         }
-        resp = await self._cmd.execute(data)
-        response_data = await resp.json()
+        response_data = await self._cmd.execute_json(data)
         results = response_data[RESULTS]
         return WebRtcStream(results, self._cmd)
 
@@ -285,7 +282,10 @@ class EventImage:
     """
 
     def __init__(
-        self, data: Mapping[str, Any], cmd: Command, event_image_type: EventImageType
+        self,
+        data: Mapping[str, Any],
+        cmd: Command,
+        event_image_type: EventImageContentType,
     ):
         """Initialize the EventImage."""
         self._data = data
@@ -293,7 +293,7 @@ class EventImage:
         self._event_image_type = event_image_type
 
     @property
-    def event_image_type(self) -> EventImageType:
+    def event_image_type(self) -> EventImageContentType:
         """Return the type of event image."""
         return self._event_image_type
 
@@ -321,46 +321,6 @@ class EventImage:
         return await self._cmd.fetch_image(fetch_url, basic_auth=self.token)
 
 
-class EventImageContents:
-    """Holds image contents and the associated event.
-
-    This object is used to represent the event image contents and associated
-    data needed for providing a lightweight cache (an id and expiration).
-    """
-
-    def __init__(
-        self,
-        event_id: str,
-        event_image_type: EventImageType,
-        expires_at: datetime.datetime,
-        contents: bytes,
-    ) -> None:
-        """Initialize ImageEventContent."""
-        self._event_id = event_id
-        self._event_image_type = event_image_type
-        self._expires_at = expires_at
-        self._contents = contents
-
-    @property
-    def event_id(self) -> str:
-        """A unique id associated with this event."""
-        return self._event_id
-
-    @property
-    def event_image_type(self) -> EventImageType:
-        return self._event_image_type
-
-    @property
-    def expires_at(self) -> datetime.datetime:
-        """Timestamp when the message expires."""
-        return self._expires_at
-
-    @property
-    def contents(self) -> bytes:
-        """Image contents captured during the event."""
-        return self._contents
-
-
 class EventImageCreator(ABC):
     """Responsible for turning events into an EventImage."""
 
@@ -387,8 +347,7 @@ class CameraEventImageTrait(EventImageCreator):
                 "eventId": event_id,
             },
         }
-        resp = await self._cmd.execute(data)
-        response_data = await resp.json()
+        response_data = await self._cmd.execute_json(data)
         results = response_data[RESULTS]
         return EventImage(results, self._cmd, EventImageType.IMAGE)
 
@@ -413,21 +372,6 @@ class EventImageGenerator(EventTrait, EventImageCreator, ABC):
             return None
         return await self.generate_event_image(event)
 
-    async def active_event_image_contents(
-        self, width: Optional[int] = None, height: Optional[int] = None
-    ) -> Optional[EventImageContents]:
-        """Downloads camera image for the active event."""
-        event = self.active_event
-        if not event:
-            return None
-        event_image = await self.generate_event_image(event)
-        if not event_image:
-            return None
-        contents = await event_image.contents(width, height)
-        return EventImageContents(
-            event.event_id, event_image.event_image_type, event.expires_at, contents
-        )
-
 
 @TRAIT_MAP.register()
 class CameraMotionTrait(EventImageGenerator):
