@@ -163,7 +163,6 @@ def CreateCreds(args: argparse.Namespace) -> Credentials:
                 "installed": {
                     "client_id": args.client_id,
                     "client_secret": args.client_secret,
-                    "redirect_uris": ["urn:ietf:wg:oauth:2.0:oob"],
                     "auth_uri": OAUTH2_AUTHORIZE_FORMAT.format(
                         project_id=args.project_id
                     ),
@@ -173,7 +172,7 @@ def CreateCreds(args: argparse.Namespace) -> Credentials:
             app_flow = InstalledAppFlow.from_client_config(
                 client_config, scopes=SDM_SCOPES
             )
-            creds = app_flow.run_console()
+            creds = app_flow.run_local_server()
         # Save the credentials for the next run
         if not os.path.exists(os.path.dirname(token_cache)):
             try:
